@@ -27,14 +27,8 @@ move.mask <- reduced.samples$total.time > 0 & reduced.samples$total.time < upper
 usable.pixels <- which.max(move.mask) # identify relevant pixels
 presence.samples <- SpatialPoints(xyFromCell(move.mask, usable.pixels), proj4string=crs(shortMove)) # build shapefile from samples (presences)
 
-## ----eval=FALSE----------------------------------------------------------
-#  sample.id <- labelSample(presence.samples, ndvi, agg.radius=60) # aggregate samples in space
-
-## ----echo=FALSE, message=FALSE-------------------------------------------
-sample.id <- read.table(list.files(system.file('extdata', '', package="rsMove"), 'sampleIndices.txt', full.names=TRUE))[,,1]
-
 ## ----message=FALSE-------------------------------------------------------
-sample.id # show indices
+sample.id <- labelSample(presence.samples, ndvi, agg.radius=60) # aggregate samples in space
 absence.samples <- backSample(presence.samples, ndvi, sample.id, sampling.method="pca") # identify absence samples
 absence.samples # show samples
 
@@ -48,7 +42,7 @@ plot(resourceModel1$probabilities >= 0.5) # probability map
 points(presence.samples) # presences
 
 ## ---- out.width="98%", fig.height=5, fig.width=10, dpi=600, fig.align="center", echo=FALSE----
-kable_styling(kable(head(resourceModel1$f1, 2), format="html", align="c", full_width=TRUE), "stripped", bootstrap_options="responsive")
+kable_styling(kable(head(resourceModel1$f1, 1), format="html", align="c", full_width=TRUE), "stripped", bootstrap_options="responsive")
 
 ## ----message=FALSE, warning=FALSE, results='hide'------------------------
 absence.samples <- backSample(presence.samples, ndvi, sampling.method="random") # identify absence samples (random)
@@ -58,7 +52,7 @@ resourceModel2 <- predictResources(env.presences, env.absences, sample.id, env.d
 ## ---- out.width="98%", fig.height=5, fig.width=10, dpi=600, fig.align="center"----
 plot(resourceModel2$probabilities >= 0.5) # probability map
 points(presence.samples) # presences
-kable_styling(kable(head(resourceModel2$f1, 2), format="html", align="c", full_width=TRUE), "stripped", bootstrap_options="responsive")
+kable_styling(kable(head(resourceModel2$f1, 1), format="html", align="c", full_width=TRUE), "stripped", bootstrap_options="responsive")
 
 ## ----message=FALSE-------------------------------------------------------
 landCover <- raster(system.file('extdata', 'landCover.tif', package="rsMove"))
